# pyOpenSourceProjects
Helper Library to organize open source Projects

[![pypi](https://img.shields.io/pypi/pyversions/pyOpenSourceProjects)](https://pypi.org/project/pyOpenSourceProjects/)
[![Github Actions Build](https://github.com/WolfgangFahl/pyOpenSourceProjects/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/pyOpenSourceProjects/actions?query=workflow%3ABuild+branch%3Amain)
[![PyPI Status](https://img.shields.io/pypi/v/pyOpenSourceProjects.svg)](https://pypi.python.org/pypi/pyOpenSourceProjects/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/pyOpenSourceProjects.svg)](https://github.com/WolfgangFahl/pyOpenSourceProjects/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pyOpenSourceProjects.svg)](https://github.com/WolfgangFahl/pyOpenSourceProjects/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/pyOpenSourceProjects.svg)](https://www.apache.org/licenses/LICENSE-2.0)


## Documentation
[Wiki](https://wiki.bitplan.com/index.php/PyOpenSourceProjects)

### Authors
* [Tim Holzheim](https://www.semantic-mediawiki.org/wiki/Tim_Holzheim)
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)